#
# spec file for package libgxps
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libgxps
Version:        0.3.2
Release:        1.12
Summary:        Library for rendering XPS documents
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://live.gnome.org/libgxps
Source0:        https://download.gnome.org/sources/libgxps/0.3/%{name}-%{version}.tar.xz
Source99:       %{name}-rpmlintrc

BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson >= 0.43.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo) >= 1.10.0
BuildRequires:  pkgconfig(cairo-pdf)
BuildRequires:  pkgconfig(cairo-ps)
BuildRequires:  pkgconfig(cairo-svg)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gio-2.0) >= 2.24
BuildRequires:  pkgconfig(glib-2.0) >= 2.24
BuildRequires:  pkgconfig(gobject-2.0) >= 2.24
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libarchive) >= 2.8.0
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)

%description
libgxps is a GObject based library for handling and rendering XPS
documents.

%package -n libgxps2
Summary:        Library for rendering XPS documents
Group:          System/Libraries

%description -n libgxps2
libgxps is a GObject based library for handling and rendering XPS
documents.

%package -n typelib-1_0-GXPS-0_1
Summary:        Library for rendering XPS documents -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GXPS-0_1
libgxps is a GObject based library for handling and rendering XPS
documents.

This package provides the GObject Introspection bindings for libgxps.

%package tools
Summary:        Tools for rendering XPS documents
Group:          Productivity/Publishing/Other

%description tools
libgxps is a GObject based library for handling and rendering XPS
documents.

%package devel
Summary:        Development files for libgxps, a XPS document render library
Group:          Development/Libraries/C and C++
Requires:       libgxps2 = %{version}
Requires:       typelib-1_0-GXPS-0_1 = %{version}

%description devel
libgxps is a GObject based library for handling and rendering XPS
documents.

%prep
%autosetup -p1

%build
%meson \
	-Denable-gtk-doc=true \
	-Denable-man=true \
	-Denable-test=false \
	%{nil}
%meson_build

%install
%meson_install

%post -n libgxps2 -p /sbin/ldconfig
%postun -n libgxps2 -p /sbin/ldconfig

%files -n libgxps2
%license COPYING
%{_libdir}/libgxps.so.2*

%files -n typelib-1_0-GXPS-0_1
%{_libdir}/girepository-1.0/GXPS-0.1.typelib

%files tools
%{_bindir}/xpstojpeg
%{_bindir}/xpstopdf
%{_bindir}/xpstopng
%{_bindir}/xpstops
%{_bindir}/xpstosvg
%{_mandir}/man1/xpstojpeg.1%{?ext_man}
%{_mandir}/man1/xpstopdf.1%{?ext_man}
%{_mandir}/man1/xpstopng.1%{?ext_man}
%{_mandir}/man1/xpstops.1%{?ext_man}
%{_mandir}/man1/xpstosvg.1%{?ext_man}

%files devel
%doc AUTHORS NEWS README
%doc %{_datadir}/gtk-doc/html/libgxps/
%{_includedir}/libgxps/
%{_libdir}/libgxps.so
%{_libdir}/pkgconfig/libgxps.pc
%{_datadir}/gir-1.0/GXPS-0.1.gir

%changelog
* Sat Feb 27 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.3.2:
  + New features: Add support to wdp images on Windows using
    WIC API.
  + Bug fixes: Fix a crash in tools when the surface is NULL on
    conversion end.
  + Build:
  - Improve dependency check on Windows.
  - Don't assume that cross builds can't generate gir.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 0.3.1:
  + Fix font scaling when converting xps to pdf.
  + Handle errors returned by archive_read_data in GXPSArchive.
  + Ensure gxps_archive_read_entry() fills the GError in case of
    failure.
  + Make the pdf generated by xpstopdf to be 96 dpi.
  + Fix OUTPUT FILE description in man pages.
  + Clear the GError before trying to load an image again in
    gxps_images_get_image().
  + Fix integer overflow in png decoder.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Aug 26 2017 jengelh@inai.de
- Fix RPM groups and summaries.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 0.3.0:
  + New features:
  - Add initial support for resource dictionaries (bgo#777731).
  - Support OpenXPS fixed representation schema (bgo#768117).
  + Bug fixes: Fix a crash when extracting a malformed file
    (bgo#785479).
  + Build: Switch to meson build system (bgo#783642).
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add gtk-doc BuildRequires, needed to build documentation, also
  build manpages.
- Add libgxps-rpmlintrc: Filter out bogus rpmlint warning about
  libgxps-tools not containing any libs.
- Run spec-cleaner, modernize spec.
* Sun Feb 26 2017 zaitor@opensuse.org
- Update to version 0.2.5:
  + Fix handling of internal documents paths to ensure we always
    use "/" instead of the system path separator (bgo#777894).
  + Improve performance when querying archive entries by using a
    hash set instead of a GList (bgo#777272).
  + Improve performance when querying documents in archive by using
    a GPtrArray instead of a GList (bgo#777269).
  + Fix a user after free in tools.
  + Fix several memory leaks.
  + Fix potential NULL pointer dereference found by coverity
    (bgo#776323).
  + Add a missing break in switch statement found by coverity
    (bgo#776323).
  + Fix uninitialised variables found by coverity (bgo#776323).
  + Fix several compile warnings.
  + Remove wrong return from print_token() that is void
    (bgo#772296).
  + Fix GObject introspection build (bgo#775637).
  + Build: Add support for building with Visual studio
    (bgo#771057).
* Mon Jun 20 2016 zaitor@opensuse.org
- Update to version 0.2.4:
  + Fix the build with GCC >= 6 when tests are enabled.
  + Fix non-literal format string warning for clang (bgo#760177).
  + Correctly show translated messages for command line tools on
    some locales (bgo#760437).
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 0.2.3.2:
  + Follow up release to fix the build in some cases due to libm
    undefined symbols.
* Sat Aug 15 2015 zaitor@opensuse.org
- Update to version 0.2.3.1:
  + This is a follow up release to fix the build in some cases due
    to libpng undefined symbols.
* Thu Aug 13 2015 zaitor@opensuse.org
- Update to version 0.2.3:
  + API changes: Add API to get Core Properties of a XPS file.
  + New features:
  - Support ImageBrush Viewbox and rotation/shearing matrices
    (bgo#751357).
  - Add support for JPEG images with GRAYSCALE color space
    (bgo#744120).
  - Add support for interleaved zip archives.
  + Bugs fixed:
  - Fix transformation for VisualBrush elements (bgo#742630).
  - Fix parsing of dash array with negative values (bgo#715023).
  - Make gxps_dash_array_parse fail for an odd number of dashes
    (bgo#715023).
  - Fix parsing of dash array when it has trailing or leading
    whitespaces (bgo#715023).
  - Fix the build with libpng16.
  - Fix parsing of real numbers containing e[+-]number.
  - Fix a crash in documents containing nested FixedDocument
    (bgo#685741).
- Drop obsolete xz BuildRequires: We now support xz tarballs by
  default.
- Drop libgxps-libpng16.patch: Fixed upstream.
* Fri Feb 15 2013 pgajdos@suse.com
- Add libgxps-libpng16.patch, also build against libpng16.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 0.2.2:
  + Bug fixes:
  - Fix COPYING file that used lgl2 instead of lgpl2.1
    (bgo#671271)
  - Fix the build with --enable-gtk-doc (bgo#671274)
  - Fix several memory leaks when parsing fails (bgo#668937,
    bgo#668940, bgo#668941, bgo#668969, bgo#668968, bgo#668966,
    bgo#668965)
  + Tools:
  - Set image parameters after jpeg_set_defaults(), so the
    resolution does not get overwritten by the defaults
  + Documentation:
  - Ignore private headers when generating API doc
  - Add index of new symbols in 0.2.1
  - Add Since: tag to GXPS_VERSION_STRING api docs
* Sat Jan 21 2012 vuntz@opensuse.org
- Update to version 0.2.1:
  + API changes:
  - Add GXPS_VERSION_STRING macro with the library version as a
    string
  + New features:
  - Support OpacityMask for Path elements (bgo#663477)
  + Bug fixes:
  - Fix MAJOR/MINOR/MICRO version macros
  - Fix FSF address in COPYING file
  - Fix building with libpng15 (bgo#664666)
  - Fix tools build by linking to libm (bgo#664439)
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop libgxps-link-libm.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  those were only needed for patch above.
* Mon Jan  9 2012 vuntz@opensuse.org
- Split typelib file into typelib-1_0-GXPS-0_1 subpackage.
- Add typelib-1_0-GXPS-0_1 Requires to devel subpackage.
* Sun Nov 20 2011 dimstar@opensuse.org
- Update to version 0.2.0:
  + API changes:
  - This release contains a small API break. Even though all of
    the XPS documents we have for testing use integer numbers for
    the page size, the XPS Specification says that page size is a
    double value. Functions gxps_page_get_size() and
    gxps_document_get_page_size() now return page width and page
    height as gdouble values instead of guint.
  + New features:
  - Add support for PolyQuadraticBezierSegment figures
  - Add support for Smooth Cubic Bézier curve
  - Initial implementation of ICC based colors. Only CMYK colors
    are supported for now
  - Support Opacity for SolidColorBrush elements (bgo#663472)
  - Add support for scRGB color syntax
  - Implement Quadratic Bézier curve
  - Support OpacityMask for Glyphs elements (bgo#66347)
  - Support OpacityMask for Canvas elements (bgo#663475)
  - Support opacity for ImageBrush elements (bgo#663471)
  - Support opacity for Glyphs elements (bgo#662654)
  - Support opacity for Canvas elements (bgo#662653)
  - Support opacity for Path elements (bgo#662652)
  - Support opacity for LinearGradientBrush and
    RadialGradientBrush elements (bgo#662655)
  + Bug fixes:
  - Fix parser error messages for invalid content (bgo#663899)
  + Tools:
  - Add xpstojpeg tool for converting XPS documents to JPEG
  - Add xpstosvg tool for converting XPS documents to SVG
  - Add xpstops tool for converting XPS documents to PostScript
  - Add xpstopdf tool for converting XPS documents to PDF
  - Add xpstopng tool for converting XPS documents to PNG
  + Updated documentation.
- Add libgxps-link-libm.patch: Add missing libm linking.
- Add gnome-common BuildRequires and call to gnome-autogen.sh for
  above patch.
- Add pkgconfig(cairo-pdf), pkgconfig(cairo-ps),
  pkgconfig(cairo-svg), pkgconfig(lcms2) and pkgconfig(libpng)
  BuildRequires: new dependencies upstream.
- Rename libgxps1 subpackage to libgxps2, following upstream
  soversion change.
- Create a tools subpackage to distribute the various new tools.
* Wed Nov 16 2011 vuntz@opensuse.org
- Initial package (0.1.0)
